@@ -560,7 +560,7 @@ int ffcalc_rng( fitsfile *infptr,   /* I - Input FITS file                  */
             return( *status = PARSE_BAD_TYPE );
          }
          parName++;  /* Advance past '#' */
-	 if ( (strcasecmp(parName,"HISTORY") == 0 || strcasecmp(parName,"COMMENT") == 0) &&
+	 if ( (fits_strcasecmp(parName,"HISTORY") == 0 || fits_strcasecmp(parName,"COMMENT") == 0) &&
 	      Info.datatype != TSTRING ) {
             ffcprs();
             ffpmsg( "HISTORY and COMMENT values must be strings (ffcalc)" );
@@ -593,7 +593,7 @@ int ffcalc_rng( fitsfile *infptr,   /* I - Input FITS file                  */
          if( parInfo==NULL || *parInfo=='\0' ) {
             /*  Figure out best default column type  */
             if( gParse.hdutype==BINARY_TBL ) {
-               sprintf(tform,"%ld",nelem);
+               snprintf(tform,15,"%ld",nelem);
                switch( Info.datatype ) {
                case TLOGICAL:  strcat(tform,"L");  break;
                case TLONG:     strcat(tform,"J");  break;
@@ -612,14 +612,14 @@ int ffcalc_rng( fitsfile *infptr,   /* I - Input FITS file                  */
                case TLONG:     strcpy(tform,"I11");     break;
                case TDOUBLE:   strcpy(tform,"D23.15");  break;
                case TSTRING:   
-               case TBIT:      sprintf(tform,"A%ld",nelem);  break;
+               case TBIT:      snprintf(tform,16,"A%ld",nelem);  break;
                }
             }
             parInfo = tform;
          } else if( !(isdigit((int) *parInfo)) && gParse.hdutype==BINARY_TBL ) {
             if( Info.datatype==TBIT && *parInfo=='B' )
                nelem = (nelem+7)/8;
-            sprintf(tform,"%ld%s",nelem,parInfo);
+            snprintf(tform,16,"%ld%s",nelem,parInfo);
             parInfo = tform;
          }
          fficol( outfptr, colNo, parName, parInfo, status );
@@ -768,9 +768,9 @@ int ffcalc_rng( fitsfile *infptr,   /* I - Input FITS file                  */
          break;
       case TBIT:
       case TSTRING:
-	 if (strcasecmp(parName,"HISTORY") == 0) {
+	 if (fits_strcasecmp(parName,"HISTORY") == 0) {
 	   ffphis( outfptr, result->value.data.str, status);
-	 } else if (strcasecmp(parName,"COMMENT") == 0) {
+	 } else if (fits_strcasecmp(parName,"COMMENT") == 0) {
 	   ffpcom( outfptr, result->value.data.str, status);
 	 } else {
 	   ffukys( outfptr, parName, result->value.data.str, parInfo, status );
@@ -1476,7 +1476,7 @@ static void Setup_DataArrays( int nCols, iteratorCol *cols,
          break;
 
       default:
-         sprintf(msg, "SetupDataArrays, unhandled type %d\n",
+         snprintf(msg, 80, "SetupDataArrays, unhandled type %d\n",
                 varData->type);
          ffpmsg(msg);
       }
@@ -2035,7 +2035,7 @@ int uncompress_hkdata( fitsfile *fptr,
                   sPtr, &anynul, status ) ) return( *status );
       parNo = gParse.nCols;
       while( parNo-- )
-         if( !strcasecmp( parName, gParse.varData[parNo].name ) ) break;
+         if( !fits_strcasecmp( parName, gParse.varData[parNo].name ) ) break;
 
       if( parNo>=0 ) {
          found[parNo] = 1; /* Flag this parameter as found */
@@ -2072,7 +2072,7 @@ int uncompress_hkdata( fitsfile *fptr,
    parNo = gParse.nCols;
    while( parNo-- )
       if( !found[parNo] ) {
-         sprintf( parName, "Parameter not found: %-30s", 
+         snprintf( parName, 256, "Parameter not found: %-30s", 
                   gParse.varData[parNo].name );
          ffpmsg( parName );
          *status = PARSE_SYNTAX_ERR;
@@ -2217,7 +2217,7 @@ static int set_image_col_types (fitsfile * fptr, const char * name, int bitpix,
          colIter->datatype = TDOUBLE;
          break;
       default:
-         sprintf(temp, "set_image_col_types: unrecognized image bitpix [%d]\n",
+         snprintf(temp, 80,"set_image_col_types: unrecognized image bitpix [%d]\n",
                 bitpix);
          ffpmsg(temp);
          return gParse.status = PARSE_BAD_TYPE;
@@ -2267,11 +2267,11 @@ if (gParse.hdutype == IMAGE_HDU) {
 
    colnum = -1;
    for (i = 0; i < gParse.pixFilter->count; ++i) {
-      if (!strcasecmp(colName, gParse.pixFilter->tag[i]))
+      if (!fits_strcasecmp(colName, gParse.pixFilter->tag[i]))
          colnum = i;
    }
    if (colnum < 0) {
-      sprintf(temp, "find_column: PixelFilter tag %s not found", colName);
+      snprintf(temp, 80, "find_column: PixelFilter tag %s not found", colName);
       ffpmsg(temp);
       gParse.status = COL_NOT_FOUND;
       return pERROR;
@@ -2341,12 +2341,12 @@ if (gParse.hdutype != IMAGE_HDU) {
       /* The datatype of column with TZERO and TSCALE keywords might be 
          float or double. 
       */
-      sprintf(temp,"TZERO%d",colnum);
+      snprintf(temp,80,"TZERO%d",colnum);
       istatus = 0;
       if(fits_read_key(fptr,TDOUBLE,temp,&tzero,NULL,&istatus)) {
           tzero = 0.0;
       } 
-      sprintf(temp,"TSCAL%d",colnum);
+      snprintf(temp,80,"TSCAL%d",colnum);
       istatus = 0;
       if(fits_read_key(fptr,TDOUBLE,temp,&tscale,NULL,&istatus)) {
           tscale = 1.0;
@@ -2390,7 +2390,7 @@ if (gParse.hdutype != IMAGE_HDU) {
       colIter->datatype = TSTRING;
       type = SCOLUMN;
       if ( width >= MAX_STRLEN ) {
-	sprintf(temp, "column %d is wider than maximum %d characters",
+	snprintf(temp, 80, "column %d is wider than maximum %d characters",
 		colnum, MAX_STRLEN-1);
         ffpmsg(temp);
 	gParse.status = PARSE_LRG_VECTOR;
@@ -2400,7 +2400,7 @@ if (gParse.hdutype != IMAGE_HDU) {
       break;
    default:
       if (typecode < 0) {
-        sprintf(temp, "variable-length array columns are not supported. typecode = %d", typecode);
+        snprintf(temp, 80,"variable-length array columns are not supported. typecode = %d", typecode);
         ffpmsg(temp);
       }
       gParse.status = PARSE_BAD_TYPE;
@@ -2441,7 +2441,7 @@ static int find_keywd(char *keyname, void *itslval )
    if( fits_read_keyword( fptr, keyname, keyvalue, NULL, &status ) ) {
       if( status == KEY_NO_EXIST ) {
          /*  Do this since ffgkey doesn't put an error message on stack  */
-         sprintf(keyvalue, "ffgkey could not find keyword: %s",keyname);
+         snprintf(keyvalue,FLEN_VALUE, "ffgkey could not find keyword: %s",keyname);
          ffpmsg(keyvalue);
       }
       gParse.status = status;
@@ -2575,7 +2575,7 @@ static int load_column( int varNum, long fRow, long nRows,
              (double *)data, undef, &anynul, &status);
       break;
    default:
-      sprintf(msg,"load_column: unexpected datatype %d", var->datatype);
+      snprintf(msg,80,"load_column: unexpected datatype %d", var->datatype);
       ffpmsg(msg);
    }
   }
@@ -2695,7 +2695,7 @@ int fits_pixel_filter (PixelFilter * filter, int * status)
          char card[FLEN_CARD];
 
          if (fits_read_record(infptr, i, card, status)) {
-            sprintf(msg, "pixel_filter: unable to read keycard %d", i);
+            snprintf(msg, 256,"pixel_filter: unable to read keycard %d", i);
             ffpmsg(msg);
             goto CLEANUP;
          }
@@ -2714,7 +2714,7 @@ int fits_pixel_filter (PixelFilter * filter, int * status)
             /* do not transfer BZERO, BSCALE to real output image */
          }
          else if (fits_write_record(outfptr, card, status)) {
-            sprintf(msg, "pixel_filter: unable to write keycard '%s' [%d]\n",
+            snprintf(msg,256, "pixel_filter: unable to write keycard '%s' [%d]\n",
                         card, *status);
             ffpmsg(msg);
             goto CLEANUP;
@@ -2730,7 +2730,7 @@ int fits_pixel_filter (PixelFilter * filter, int * status)
       case DOUBLE_IMG: datatype = TDOUBLE; Info.datatype = TDOUBLE; break;
 
       default:
-           sprintf(msg, "pixel_filter: unexpected output bitpix %d\n", bitpix);
+           snprintf(msg, 256,"pixel_filter: unexpected output bitpix %d\n", bitpix);
            ffpmsg(msg);
            *status = pERROR;
            goto CLEANUP;
@@ -2826,7 +2826,7 @@ int fits_pixel_filter (PixelFilter * filter, int * status)
          ffukys(outfptr, parName, result->value.data.str, parInfo, status);
          break;
       default:
-         sprintf(msg, "pixel_filter: unexpected constant result type [%d]\n",
+         snprintf(msg, 256,"pixel_filter: unexpected constant result type [%d]\n",
                 Info.datatype);
          ffpmsg(msg);
       }
