@@ -42,6 +42,10 @@ standard_column_names = {
     6: ["II", "IQ", "IU", "QQ", "QU", "UU"],
 }
 
+allowed_paths = tuple(six.string_types)
+if sys.version >= "3.4":
+    allowed_paths += (pathlib.Path,)
+
 
 class HealpixFitsWarning(Warning):
     pass
@@ -60,8 +64,14 @@ def read_cl(filename):
     cl : array
       the cl array
     """
+    opened_file = False
+    if isinstance(filename, allowed_paths):
+        filename = pf.open(filename)
+        opened_file = True
     fits_hdu = _get_hdu(filename, hdu=1)
     cl = np.array([fits_hdu.data.field(n) for n in range(len(fits_hdu.columns))])
+    if opened_file:
+        filename.close()
     if len(cl) == 1:
         return cl[0]
     else:
@@ -89,7 +99,8 @@ def write_cl(filename, cl, dtype=None, overwrite=False):
         warnings.warn(
             "The default dtype of write_cl() will change in a future version: "
             "explicitly set the dtype if it is important to you",
-            category=FutureWarning)
+            category=FutureWarning,
+        )
         dtype = np.float64
         # At some poin change this to:
         # dtype = cl.dtype if isinstance(cl, np.ndarray) else cl[0].dtype
@@ -110,7 +121,9 @@ def write_cl(filename, cl, dtype=None, overwrite=False):
     tbhdu = pf.BinTableHDU.from_columns(cols)
     # add needed keywords
     tbhdu.header["CREATOR"] = "healpy"
-    tbhdu.writeto(filename, overwrite=overwrite)
+    # Add str to convert pathlib.Path into str
+    # Due to https://github.com/astropy/astropy/issues/10594
+    tbhdu.writeto(str(filename), overwrite=overwrite)
 
 
 def write_map(
@@ -184,7 +197,8 @@ def write_map(
         warnings.warn(
             "The default dtype of write_map() will change in a future version: "
             "explicitly set the dtype if it is important to you",
-            category=FutureWarning)
+            category=FutureWarning,
+        )
         dtype = [np.float32 for x in m]
         # Change this at some point to:
         # dtype = [x.dtype for x in m]
@@ -282,7 +296,9 @@ def write_map(
     for args in extra_header:
         tbhdu.header[args[0]] = args[1:]
 
-    tbhdu.writeto(filename, overwrite=overwrite)
+    # Add str to convert pathlib.Path into str
+    # Due to https://github.com/astropy/astropy/issues/10594
+    tbhdu.writeto(str(filename), overwrite=overwrite)
 
 
 def read_map(
@@ -336,7 +352,8 @@ def read_map(
     h : bool, optional
       If True, return also the header. Default: False.
     verbose : bool, optional
-      If True, print a number of diagnostic messages
+      If True, print a number of diagnostic messages, call hp.disable_warnings() to
+      disable warnings for all functions.
     memmap : bool, optional
       Argument passed to astropy.io.fits.open, if True, the map is not read into memory,
       but only the required pixels are read when needed. Default: False.
@@ -353,19 +370,25 @@ def read_map(
             "np.float64 dtype of read_map(), please consider that it will "
             "change in a future version to None as to keep the same dtype of "
             "the input file: please explicitly set the dtype if it is "
-            "important to you.")
+            "important to you."
+        )
+
+    opened_file = False
+    if isinstance(filename, allowed_paths):
+        filename = pf.open(filename, memmap=memmap)
+        opened_file = True
 
     fits_hdu = _get_hdu(filename, hdu=hdu, memmap=memmap)
 
     nside = fits_hdu.header.get("NSIDE")
-    if nside is None:
+    if nside is None and verbose:
         warnings.warn(
             "No NSIDE in the header file : will use length of array", HealpixFitsWarning
         )
     else:
         nside = int(nside)
     if verbose:
-        print("NSIDE = {0:d}".format(nside))
+        warnings.warn("NSIDE = {0:d}".format(nside))
 
     if not pixelfunc.isnsideok(nside):
         raise ValueError("Wrong nside parameter.")
@@ -374,7 +397,7 @@ def read_map(
         ordering = nest and "NESTED" or "RING"
         warnings.warn("No ORDERING keyword in header file : " "assume %s" % ordering)
     if verbose:
-        print("ORDERING = {0:s} in fits file".format(ordering))
+        warnings.warn("ORDERING = {0:s} in fits file".format(ordering))
 
     sz = pixelfunc.nside2npix(nside)
     ret = []
@@ -402,7 +425,7 @@ def read_map(
         schm = partial and "EXPLICIT" or "IMPLICIT"
         warnings.warn("No INDXSCHM keyword in header file : " "assume {}".format(schm))
     if verbose:
-        print("INDXSCHM = {0:s}".format(schm))
+        warnings.warn("INDXSCHM = {0:s}".format(schm))
 
     if field is None:
         field = range(len(fits_hdu.data.columns) - 1 * partial)
@@ -415,8 +438,8 @@ def read_map(
         try:
             pix = fits_hdu.data.field(0).astype(int, copy=False).ravel()
         except pf.VerifyError as e:
-            print(e)
-            print("Trying to fix a badly formatted header")
+            warnings.warn(e)
+            warnings.warn("Trying to fix a badly formatted header")
             fits_hdu.verify("fix")
             pix = fits_hdu.data.field(0).astype(int, copy=False).ravel()
 
@@ -434,8 +457,8 @@ def read_map(
             else:
                 m = fits_hdu.data.field(ff).astype(curr_dtype, copy=False).ravel()
         except pf.VerifyError as e:
-            print(e)
-            print("Trying to fix a badly formatted header")
+            warnings.warn(e)
+            warnings.warn("Trying to fix a badly formatted header")
             m = fits_hdu.verify("fix")
             if curr_dtype is None:
                 m = fits_hdu.data.field(ff).ravel()
@@ -448,19 +471,19 @@ def read_map(
             m = mnew
 
         if (not pixelfunc.isnpixok(m.size) or (sz > 0 and sz != m.size)) and verbose:
-            print("nside={0:d}, sz={1:d}, m.size={2:d}".format(nside, sz, m.size))
+            warnings.warn("nside={0:d}, sz={1:d}, m.size={2:d}".format(nside, sz, m.size))
             raise ValueError("Wrong nside parameter.")
         if not nest is None:  # no conversion with None
             if nest and ordering == "RING":
                 idx = pixelfunc.nest2ring(nside, np.arange(m.size, dtype=np.int32))
                 m = m[idx]
                 if verbose:
-                    print("Ordering converted to NEST")
+                    warnings.warn("Ordering converted to NEST")
             elif (not nest) and ordering == "NESTED":
                 idx = pixelfunc.ring2nest(nside, np.arange(m.size, dtype=np.int32))
                 m = m[idx]
                 if verbose:
-                    print("Ordering converted to RING")
+                    warnings.warn("Ordering converted to RING")
         try:
             m[pixelfunc.mask_bad(m)] = UNSEEN
         except OverflowError:
@@ -472,6 +495,9 @@ def read_map(
         for (key, value) in fits_hdu.header.items():
             header.append((key, value))
 
+    if opened_file:
+        filename.close()
+
     if len(ret) == 1:
         if h:
             return ret[0], header
@@ -572,7 +598,9 @@ def write_alm(
 
         tbhdu = pf.BinTableHDU.from_columns([cindex, creal, cimag])
         hdulist.append(tbhdu)
-    hdulist.writeto(filename, overwrite=overwrite)
+    # Add str to convert pathlib.Path into str
+    # Due to https://github.com/astropy/astropy/issues/10594
+    hdulist.writeto(str(filename), overwrite=overwrite)
 
 
 def read_alm(filename, hdu=1, return_mmax=False):
@@ -600,6 +628,12 @@ def read_alm(filename, hdu=1, return_mmax=False):
     alms = []
     lmaxtot = None
     mmaxtot = None
+
+    opened_file = False
+    if isinstance(filename, allowed_paths):
+        filename = pf.open(filename)
+        opened_file = True
+
     for unit in np.atleast_1d(hdu):
         idx, almr, almi = [_get_hdu(filename, hdu=unit).data.field(i) for i in range(3)]
         l = np.floor(np.sqrt(idx - 1)).astype(np.long)
@@ -622,6 +656,8 @@ def read_alm(filename, hdu=1, return_mmax=False):
         alm.real[i] = almr
         alm.imag[i] = almi
         alms.append(alm)
+    if opened_file:
+        filename.close()
     if len(alms) == 1:
         alm = alms[0]
     else:
@@ -649,10 +685,6 @@ def _get_hdu(input_data, hdu=None, memmap=None):
     fits_hdu : HDU
         The extracted HDU
     """
-    allowed_paths = tuple(six.string_types)
-    if sys.version >= "3.4":
-        allowed_paths += (pathlib.Path, pathlib.PosixPath)
-
     if isinstance(input_data, allowed_paths):
         hdulist = pf.open(input_data, memmap=memmap)
         return _get_hdu(hdulist, hdu=hdu)
