@@ -17,6 +17,7 @@
 #
 #  For more information about Healpy, see http://code.google.com/p/healpy
 #
+import warnings
 from . import projector as P
 from . import rotator as R
 from . import pixelfunc
@@ -24,6 +25,7 @@ import matplotlib
 import matplotlib.axes
 import numpy as np
 import six
+import copy
 
 from ._healpy_pixel_lib import UNSEEN
 
@@ -536,7 +538,7 @@ class SphericalProjAxes(matplotlib.axes.Axes):
         if u_mmax:
             mmax = u_pmax
         if verbose:
-            print(
+            warnings.warn(
                 "{0} {1} {2} {3}".format(
                     pmin / dtor, pmax / dtor, mmin / dtor, mmax / dtor
                 )
@@ -620,7 +622,7 @@ class SphericalProjAxes(matplotlib.axes.Axes):
                         if l in self.lines:
                             self.lines.remove(l)
                         else:
-                            print("line not in lines")
+                            warnings.warn("line not in lines")
             del self._graticules
 
     def _get_interv_graticule(self, pmin, pmax, dpar, mmin, mmax, dmer, verbose=True):
@@ -651,7 +653,7 @@ class SphericalProjAxes(matplotlib.axes.Axes):
         vdeg = int(np.floor(np.around(dpar / dtor, 10)))
         varcmin = (dpar / dtor - vdeg) * 60.0
         if verbose:
-            print(
+            warnings.warn(
                 "The interval between parallels is {0:d} deg {1:.2f}'.".format(
                     vdeg, varcmin
                 )
@@ -659,7 +661,7 @@ class SphericalProjAxes(matplotlib.axes.Axes):
         vdeg = int(np.floor(np.around(dmer / dtor, 10)))
         varcmin = (dmer / dtor - vdeg) * 60.0
         if verbose:
-            print(
+            warnings.warn(
                 "The interval between meridians is {0:d} deg {1:.2f}'.".format(
                     vdeg, varcmin
                 )
@@ -889,6 +891,17 @@ def get_color_table(vmin, vmax, val, cmap=None, norm=None,
 
 
 def create_colormap(cmap, badcolor="gray", bgcolor="white"):
+    """Create a new colormap with specified bad/background colors.
+
+    Parameters
+    ----------
+    cmap : string or matplotlib.colors.Colormap
+        type of colormap to create
+    badcolor : string
+        color for bad pixels (passed to set_bad)
+    bgcolor : string
+        color for background (passed to set_under)
+    """
     if type(cmap) == str:
         cmap0 = matplotlib.cm.get_cmap(cmap)
     elif type(cmap) in [
@@ -903,7 +916,7 @@ def create_colormap(cmap, badcolor="gray", bgcolor="white"):
             "newcm", cmap0._segmentdata, cmap0.N
         )
     else:
-        newcm = cmap0
+        newcm = copy.deepcopy(cmap0)
     newcm.set_over(newcm(1.0))
     newcm.set_under(bgcolor)
     newcm.set_bad(badcolor)
