@@ -21,13 +21,12 @@ import warnings
 import numpy as np
 import six
 
-pi = np.pi
-import warnings
 import astropy.io.fits as pf
 from scipy.integrate import trapz
 from astropy.utils import data
 
 DATAURL = "https://healpy.github.io/healpy-data/"
+DATAURL_MIRROR = "https://github.com/healpy/healpy-data/releases/download/"
 
 from . import _healpy_sph_transform_lib as sphtlib
 from . import _sphtools as _sphtools
@@ -45,8 +44,8 @@ class FutureChangeWarning(UserWarning):
 
 DATAPATH = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
 MAX_NSIDE = (
-    8192
-)  # The maximum nside up to which most operations (e.g. map2alm) will work
+    8192  # The maximum nside up to which most operations (e.g. map2alm) will work
+)
 
 # Spherical harmonics transformation
 def anafast(
@@ -67,6 +66,10 @@ def anafast(
     between two maps if *map2* is given.
     No removal of monopole or dipole is performed. The input maps must be
     in ring-ordering.
+    Spherical harmonics transforms in HEALPix are always on the full sky,
+    if the map is masked, those pixels are set to 0. It is recommended to
+    remove monopole from the map before running `anafast` to reduce
+    boundary effects.
 
     Parameters
     ----------
@@ -99,6 +102,7 @@ def anafast(
       pixels at latitude in [-gal_cut;+gal_cut] are not taken into account
     use_pixel_weights: bool, optional
       If True, use pixel by pixel weighting, healpy will automatically download the weights, if needed
+      See the map2alm docs for details about weighting
 
     Returns
     -------
@@ -159,10 +163,30 @@ def map2alm(
     datapath=None,
     gal_cut=0,
     use_pixel_weights=False,
+    verbose=True,
 ):
     """Computes the alm of a Healpix map. The input maps must all be
     in ring ordering.
 
+
+    Pixel values are weighted before applying the transform:
+
+    * when you don't specify any weights, the uniform weight value 4*pi/n_pix is used
+    * with ring weights enabled (use_weights=True), pixels in every ring
+      are weighted with a uniform value similar to the one above, ring weights are
+      included in healpy
+    * with pixel weights (use_pixel_weights=True), every pixel gets an individual weight
+
+    Pixel weights provide the most accurate transform, so you should always use them if
+    possible. However they are not included in healpy and will be automatically downloaded
+    and cached in ~/.astropy the first time you compute a trasform at a specific nside.
+    If datapath is specified, healpy will first check that local folder before downloading
+    the weights.
+    The easiest way to setup the folder is to clone the healpy-data repository:
+    git clone --depth 1 https://github.com/healpy/healpy-data
+    and add the NSIDE 8192 weight from https://github.com/healpy/healpy-data/releases
+    and set datapath to the root of the repository.
+
     Parameters
     ----------
     maps : array-like, shape (Npix,) or (n, Npix)
@@ -187,6 +211,8 @@ def map2alm(
       pixels at latitude in [-gal_cut;+gal_cut] are not taken into account
     use_pixel_weights: bool, optional
       If True, use pixel by pixel weighting, healpy will automatically download the weights, if needed
+    verbose : bool, optional
+      If True prints diagnostic information. Default: True
 
     Returns
     -------
@@ -205,18 +231,30 @@ def map2alm(
     nside = pixelfunc.get_nside(maps)
     check_max_nside(nside)
 
+    pixel_weights_filename = None
     if use_pixel_weights:
         if use_weights:
             raise RuntimeError("Either use pixel or ring weights")
-        with data.conf.set_temp("dataurl", DATAURL), data.conf.set_temp(
-            "remote_timeout", 30
-        ):
-            pixel_weights_filename = data.get_pkg_data_filename(
-                "full_weights/healpix_full_weights_nside_%04d.fits" % nside,
-                package="healpy",
-            )
-    else:
-        pixel_weights_filename = None
+        filename = "full_weights/healpix_full_weights_nside_%04d.fits" % nside
+        if datapath is not None:
+            pixel_weights_filename = os.path.join(datapath, filename)
+            if os.path.exists(pixel_weights_filename):
+                if verbose:
+                    warnings.warn(
+                        "Accessing pixel weights from {}".format(pixel_weights_filename)
+                    )
+            else:
+                raise RuntimeError(
+                    "You specified datapath but pixel weights file"
+                    "is missing at {}".format(pixel_weights_filename)
+                )
+        if pixel_weights_filename is None:
+            with data.conf.set_temp("dataurl", DATAURL), data.conf.set_temp(
+                "dataurl_mirror", DATAURL_MIRROR
+            ), data.conf.set_temp("remote_timeout", 30):
+                pixel_weights_filename = data.get_pkg_data_filename(
+                    filename, package="healpy"
+                )
 
     if pol or info in (0, 1):
         alms = _sphtools.map2alm(
@@ -572,14 +610,22 @@ class Alm(object):
           The index for which to compute the l and m.
           If None, the function return l and m for i=0..Alm.getsize(lmax)
         """
+        szalm = Alm.getsize(lmax, lmax)
         if i is None:
-            i = np.arange(Alm.getsize(lmax))
-        m = (
-            np.ceil(
-                ((2 * lmax + 1) - np.sqrt((2 * lmax + 1) ** 2 - 8 * (i - lmax))) / 2
-            )
-        ).astype(int)
-        l = i - m * (2 * lmax + 1 - m) // 2
+            i = np.arange(szalm)
+        assert (
+            np.max(i) < szalm
+        ), "Invalid index, it should less than the max alm array length of {}".format(
+            szalm
+        )
+
+        with np.errstate(all="raise"):
+            m = (
+                np.ceil(
+                    ((2 * lmax + 1) - np.sqrt((2 * lmax + 1) ** 2 - 8 * (i - lmax))) / 2
+                )
+            ).astype(int)
+            l = i - m * (2 * lmax + 1 - m) // 2
         return (l, m)
 
     @staticmethod
@@ -759,6 +805,7 @@ def smoothalm(
       of type complex128. Otherwise, a copy of alm is made. Default: True.
     verbose : bool, optional
       If True prints diagnostic information. Default: True
+      Call hp.disable_warnings() to disable warnings for all functions.
 
     Returns
     -------
@@ -772,18 +819,18 @@ def smoothalm(
 
     if verbose:
         if beam_window is None:
-            print(
+            warnings.warn(
                 "Sigma is {0:f} arcmin ({1:f} rad) ".format(
-                    sigma * 60 * 180 / pi, sigma
+                    sigma * 60 * 180 / np.pi, sigma
                 )
             )
-            print(
+            warnings.warn(
                 "-> fwhm is {0:f} arcmin".format(
-                    sigma * 60 * 180 / pi * (2.0 * np.sqrt(2.0 * np.log(2.0)))
+                    sigma * 60 * 180 / np.pi * (2.0 * np.sqrt(2.0 * np.log(2.0)))
                 )
             )
         else:
-            print("Using provided beam window function")
+            warnings.warn("Using provided beam window function")
 
     # Check alms
     if not cb.is_seq(alms):
@@ -884,6 +931,7 @@ def smoothing(
       If True, use the ring weighting. Default: False.
     use_pixel_weights: bool, optional
       If True, use pixel by pixel weighting, healpy will automatically download the weights, if needed
+      See the map2alm docs for details about weighting
     datapath : None or str, optional
       If given, the directory where to find the weights data.
     verbose : bool, optional
@@ -927,10 +975,14 @@ def smoothing(
             fwhm=fwhm,
             sigma=sigma,
             beam_window=beam_window,
-            inplace=True,
+            pol=pol,
+            mmax=mmax,
             verbose=verbose,
+            inplace=True,
+        )
+        output_map = alm2map(
+            alms, nside, lmax=lmax, mmax=mmax, pixwin=False, verbose=verbose, pol=pol,
         )
-        output_map = alm2map(alms, nside, pixwin=False, verbose=verbose)
     else:
         # Treat each map independently (any number)
         output_map = []
@@ -1143,7 +1195,7 @@ def bl2beam(bl, theta):
         p1 = p2
         beam += bl[l] * p2 * (2 * l + 1)
 
-    beam /= 4 * pi
+    beam /= 4 * np.pi
 
     return beam
 
@@ -1172,7 +1224,7 @@ def beam2bl(beam, theta, lmax):
     nx = len(theta)
     nb = len(beam)
     if nb != nx:
-        print("beam and theta must have same size!")
+        warnings.warn("beam and theta must have same size!")
 
     x = np.cos(theta)
     st = np.sin(theta)
@@ -1190,7 +1242,7 @@ def beam2bl(beam, theta, lmax):
         p0 = p1
         p1 = p2
 
-    window *= 2 * pi
+    window *= 2 * np.pi
 
     return window
 
