@@ -94,6 +94,7 @@ def mollview(
     notext=False,
     norm=None,
     hold=False,
+    reuse_axes=False,
     margins=None,
     sub=None,
     nlocs=2,
@@ -163,6 +164,10 @@ def mollview(
     sub : int, scalar or sequence, optional
       Use only a zone of the current figure (same syntax as subplot).
       Default: None
+    reuse_axes : bool, optional
+      If True, reuse the current Axes (should be a MollweideAxes). This is
+      useful if you want to overplot with a partially transparent colormap,
+      such as for plotting a line integral convolution. Default: False
     margins : None or sequence, optional
       Either None, or a sequence (left,bottom,right,top)
       giving the margins on left,bottom,right and top
@@ -178,11 +183,15 @@ def mollview(
     # Create the figure
     import pylab
 
+    if map is None:
+        map = np.zeros(12) + np.inf
+        cbar = False
+
     # Ensure that the nside is valid
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
-    if not (hold or sub):
+    if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(8.5, 5.4))
         extent = (0.02, 0.05, 0.96, 0.9)
     elif hold:
@@ -190,6 +199,8 @@ def mollview(
         left, bottom, right, top = np.array(f.gca().get_position()).ravel()
         extent = (left, bottom, right - left, top - bottom)
         f.delaxes(f.gca())
+    elif reuse_axes:
+        f = pylab.gcf()
     else:  # using subplot syntax
         f = pylab.gcf()
         if hasattr(sub, "__len__"):
@@ -220,14 +231,14 @@ def mollview(
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
     try:
-        if map is None:
-            map = np.zeros(12) + np.inf
-            cbar = False
         map = pixelfunc.ma_to_array(map)
-        ax = PA.HpxMollweideAxes(
-            f, extent, coord=coord, rot=rot, format=format2, flipconv=flip
-        )
-        f.add_axes(ax)
+        if reuse_axes:
+            ax = f.gca()
+        else:
+            ax = PA.HpxMollweideAxes(
+                f, extent, coord=coord, rot=rot, format=format2, flipconv=flip
+            )
+            f.add_axes(ax)
         if remove_dip:
             map = pixelfunc.remove_dipole(
                 map, gal_cut=gal_cut, nest=nest, copy=True, verbose=True
@@ -336,6 +347,7 @@ def gnomview(
     norm=None,
     hold=False,
     sub=None,
+    reuse_axes=False,
     margins=None,
     notext=False,
     return_projected_map=False,
@@ -395,12 +407,16 @@ def gnomview(
     bgcolor : str
       Color to use for background
     hold : bool, optional
-      If True, replace the current Axes by a MollweideAxes.
+      If True, replace the current Axes by a GnomonicAxes.
       use this if you want to have multiple maps on the same
       figure. Default: False
     sub : int or sequence, optional
       Use only a zone of the current figure (same syntax as subplot).
       Default: None
+    reuse_axes : bool, optional
+      If True, reuse the current Axes (should be a GnomonicAxes). This is
+      useful if you want to overplot with a partially transparent colormap,
+      such as for plotting a line integral convolution. Default: False
     margins : None or sequence, optional
       Either None, or a sequence (left,bottom,right,top)
       giving the margins on left,bottom,right and top
@@ -419,11 +435,15 @@ def gnomview(
     """
     import pylab
 
+    if map is None:
+        map = np.zeros(12) + np.inf
+        cbar = False
+
     # Ensure that the nside is valid
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
-    if not (hold or sub):
+    if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(5.8, 6.4))
         if not margins:
             margins = (0.075, 0.05, 0.075, 0.05)
@@ -435,6 +455,8 @@ def gnomview(
             margins = (0.0, 0.0, 0.0, 0.0)
         extent = (left, bottom, right - left, top - bottom)
         f.delaxes(pylab.gca())
+    elif reuse_axes:
+        f = pylab.gcf()
     else:  # using subplot syntax
         f = pylab.gcf()
         if hasattr(sub, "__len__"):
@@ -464,14 +486,14 @@ def gnomview(
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
     try:
-        if map is None:
-            map = np.zeros(12) + np.inf
-            cbar = False
         map = pixelfunc.ma_to_array(map)
-        ax = PA.HpxGnomonicAxes(
-            f, extent, coord=coord, rot=rot, format=format, flipconv=flip
-        )
-        f.add_axes(ax)
+        if reuse_axes:
+            ax = f.gca()
+        else:
+            ax = PA.HpxGnomonicAxes(
+                f, extent, coord=coord, rot=rot, format=format, flipconv=flip
+            )
+            f.add_axes(ax)
         if remove_dip:
             map = pixelfunc.remove_dipole(map, gal_cut=gal_cut, nest=nest, copy=True)
         elif remove_mono:
@@ -609,6 +631,7 @@ def cartview(
     aspect=None,
     hold=False,
     sub=None,
+    reuse_axes=False,
     margins=None,
     notext=False,
     return_projected_map=False,
@@ -680,6 +703,10 @@ def cartview(
     sub : int, scalar or sequence, optional
       Use only a zone of the current figure (same syntax as subplot).
       Default: None
+    reuse_axes : bool, optional
+      If True, reuse the current Axes (should be a CartesianAxes). This is
+      useful if you want to overplot with a partially transparent colormap,
+      such as for plotting a line integral convolution. Default: False
     margins : None or sequence, optional
       Either None, or a sequence (left,bottom,right,top)
       giving the margins on left,bottom,right and top
@@ -694,11 +721,15 @@ def cartview(
     """
     import pylab
 
+    if map is None:
+        map = np.zeros(12) + np.inf
+        cbar = False
+
     # Ensure that the nside is valid
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
-    if not (hold or sub):
+    if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(8.5, 5.4))
         if not margins:
             margins = (0.075, 0.05, 0.075, 0.05)
@@ -710,6 +741,8 @@ def cartview(
             margins = (0.0, 0.0, 0.0, 0.0)
         extent = (left, bottom, right - left, top - bottom)
         f.delaxes(pylab.gca())
+    elif reuse_axes:
+        f = pylab.gcf()
     else:  # using subplot syntax
         f = pylab.gcf()
         if hasattr(sub, "__len__"):
@@ -739,9 +772,6 @@ def cartview(
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
     try:
-        if map is None:
-            map = np.zeros(12) + np.inf
-            cbar = False
         map = pixelfunc.ma_to_array(map)
         if zat and rot:
             raise ValueError("Only give rot or zat, not both")
@@ -749,10 +779,13 @@ def cartview(
             rot = np.array(zat, dtype=np.float64)
             rot.resize(3)
             rot[1] -= 90
-        ax = PA.HpxCartesianAxes(
-            f, extent, coord=coord, rot=rot, format=format, flipconv=flip
-        )
-        f.add_axes(ax)
+        if reuse_axes:
+            ax = f.gca()
+        else:
+            ax = PA.HpxCartesianAxes(
+                f, extent, coord=coord, rot=rot, format=format, flipconv=flip
+            )
+            f.add_axes(ax)
         if remove_dip:
             map = pixelfunc.remove_dipole(map, gal_cut=gal_cut, nest=nest, copy=True)
         elif remove_mono:
@@ -864,6 +897,7 @@ def orthview(
     hold=False,
     margins=None,
     sub=None,
+    reuse_axes=False,
     return_projected_map=False,
 ):
     """Plot a healpix map (given as an array) in Orthographic projection.
@@ -932,6 +966,10 @@ def orthview(
     sub : int, scalar or sequence, optional
       Use only a zone of the current figure (same syntax as subplot).
       Default: None
+    reuse_axes : bool, optional
+      If True, reuse the current Axes (should be a OrthographicAxes). This is
+      useful if you want to overplot with a partially transparent colormap,
+      such as for plotting a line integral convolution. Default: False
     margins : None or sequence, optional
       Either None, or a sequence (left,bottom,right,top)
       giving the margins on left,bottom,right and top
@@ -947,11 +985,15 @@ def orthview(
     # Create the figure
     import pylab
 
+    if map is None:
+        map = np.zeros(12) + np.inf
+        cbar = False
+
     # Ensure that the nside is valid
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
-    if not (hold or sub):
+    if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(8.5, 5.4))
         extent = (0.02, 0.05, 0.96, 0.9)
     elif hold:
@@ -959,6 +1001,8 @@ def orthview(
         left, bottom, right, top = np.array(f.gca().get_position()).ravel()
         extent = (left, bottom, right - left, top - bottom)
         f.delaxes(f.gca())
+    elif reuse_axes:
+        f = pylab.gcf()
     else:  # using subplot syntax
         f = pylab.gcf()
         if hasattr(sub, "__len__"):
@@ -989,13 +1033,13 @@ def orthview(
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
     try:
-        if map is None:
-            map = np.zeros(12) + np.inf
-            cbar = False
-        ax = PA.HpxOrthographicAxes(
-            f, extent, coord=coord, rot=rot, format=format2, flipconv=flip
-        )
-        f.add_axes(ax)
+        if reuse_axes:
+            ax = f.gca()
+        else:
+            ax = PA.HpxOrthographicAxes(
+                f, extent, coord=coord, rot=rot, format=format2, flipconv=flip
+            )
+            f.add_axes(ax)
         if remove_dip:
             map = pixelfunc.remove_dipole(
                 map, gal_cut=gal_cut, nest=nest, copy=True, verbose=True
@@ -1109,6 +1153,7 @@ def azeqview(
     aspect=None,
     hold=False,
     sub=None,
+    reuse_axes=False,
     margins=None,
     notext=False,
     return_projected_map=False,
@@ -1187,6 +1232,10 @@ def azeqview(
     sub : int, scalar or sequence, optional
       Use only a zone of the current figure (same syntax as subplot).
       Default: None
+    reuse_axes : bool, optional
+      If True, reuse the current Axes (should be a AzimuthalAxes). This is
+      useful if you want to overplot with a partially transparent colormap,
+      such as for plotting a line integral convolution. Default: False
     margins : None or sequence, optional
       Either None, or a sequence (left,bottom,right,top)
       giving the margins on left,bottom,right and top
@@ -1202,11 +1251,15 @@ def azeqview(
     # Create the figure
     import pylab
 
+    if map is None:
+        map = np.zeros(12) + np.inf
+        cbar = False
+
     # Ensure that the nside is valid
     nside = pixelfunc.get_nside(map)
     pixelfunc.check_nside(nside, nest=nest)
 
-    if not (hold or sub):
+    if not (hold or sub or reuse_axes):
         f = pylab.figure(fig, figsize=(8.5, 5.4))
         extent = (0.02, 0.05, 0.96, 0.9)
     elif hold:
@@ -1214,6 +1267,8 @@ def azeqview(
         left, bottom, right, top = np.array(f.gca().get_position()).ravel()
         extent = (left, bottom, right - left, top - bottom)
         f.delaxes(f.gca())
+    elif reuse_axes:
+        f = pylab.gcf()
     else:  # using subplot syntax
         f = pylab.gcf()
         if hasattr(sub, "__len__"):
@@ -1244,13 +1299,13 @@ def azeqview(
     wasinteractive = pylab.isinteractive()
     pylab.ioff()
     try:
-        if map is None:
-            map = np.zeros(12) + np.inf
-            cbar = False
-        ax = PA.HpxAzimuthalAxes(
-            f, extent, coord=coord, rot=rot, format=format, flipconv=flip
-        )
-        f.add_axes(ax)
+        if reuse_axes:
+            ax = f.gca()
+        else:
+            ax = PA.HpxAzimuthalAxes(
+                f, extent, coord=coord, rot=rot, format=format, flipconv=flip
+            )
+            f.add_axes(ax)
         if remove_dip:
             map = pixelfunc.remove_dipole(
                 map, gal_cut=gal_cut, nest=nest, copy=True, verbose=True
