@@ -18,6 +18,7 @@
 #  For more information about Healpy, see http://code.google.com/p/healpy
 #
 
+import warnings
 from . import projaxes as PA
 from . import rotator as R
 import numpy as np
@@ -425,12 +426,12 @@ class ZoomTool(object):
         elif ev.key == "t":
             self._increase_reso()
         elif ev.key == "p":
-            print("lon,lat = %.17g,%.17g" % (self.lon, self.lat))
+            warnings.warn("lon,lat = %.17g,%.17g" % (self.lon, self.lat))
         elif ev.key == "c":
             self._move_zoom_center(0, 0)
             self.draw_gnom(0, 0)
         elif ev.key == "v":
-            print("val = %.17g" % (self.lastval))
+            warnings.warn("val = %.17g" % (self.lastval))
         elif ev.key == "f":
             self._range_status += 1
             self._range_status %= 3
